@@ -99,6 +99,8 @@ class BaseServer(metaclass=abc.ABCMeta):
         self.deployment_flavor = ''
         self.show_image_direct_url = False
         self.show_multiple_locations = False
+        self.do_secure_hash = True
+        self.http_retries = '3'
         self.property_protection_file = ''
         self.needs_database = False
         self.log_file = None
@@ -416,9 +418,6 @@ class ApiServer(Server):
         self.user_storage_quota = '0'
         self.lock_path = self.test_dir
 
-        self.location_strategy = 'location_order'
-        self.store_type_location_strategy_preference = ""
-
         self.node_staging_uri = 'file://%s' % os.path.join(
             self.test_dir, 'staging')
 
@@ -437,6 +436,8 @@ image_cache_dir = %(image_cache_dir)s
 image_cache_driver = %(image_cache_driver)s
 show_image_direct_url = %(show_image_direct_url)s
 show_multiple_locations = %(show_multiple_locations)s
+do_secure_hash = %(do_secure_hash)s
+http_retries = %(http_retries)s
 user_storage_quota = %(user_storage_quota)s
 lock_path = %(lock_path)s
 property_protection_file = %(property_protection_file)s
@@ -445,8 +446,6 @@ image_member_quota=%(image_member_quota)s
 image_property_quota=%(image_property_quota)s
 image_tag_quota=%(image_tag_quota)s
 image_location_quota=%(image_location_quota)s
-location_strategy=%(location_strategy)s
-allow_additional_image_properties = True
 node_staging_uri=%(node_staging_uri)s
 [database]
 connection = %(sql_connection)s
@@ -456,8 +455,6 @@ policy_default_rule = %(policy_default_rule)s
 enforce_new_defaults=%(enforce_new_defaults)s
 [paste_deploy]
 flavor = %(deployment_flavor)s
-[store_type_location_strategy]
-store_type_preference = %(store_type_location_strategy_preference)s
 [glance_store]
 filesystem_store_datadir=%(image_dir)s
 default_store = %(default_store)s
@@ -606,9 +603,6 @@ class ApiServerForMultipleBackend(Server):
         self.user_storage_quota = '0'
         self.lock_path = self.test_dir
 
-        self.location_strategy = 'location_order'
-        self.store_type_location_strategy_preference = ""
-
         self.conf_base = """[DEFAULT]
 debug = %(debug)s
 default_log_levels = eventlet.wsgi.server=DEBUG,stevedore.extension=INFO
@@ -624,6 +618,8 @@ image_cache_dir = %(image_cache_dir)s
 image_cache_driver = %(image_cache_driver)s
 show_image_direct_url = %(show_image_direct_url)s
 show_multiple_locations = %(show_multiple_locations)s
+do_secure_hash = %(do_secure_hash)s
+http_retries = %(http_retries)s
 user_storage_quota = %(user_storage_quota)s
 lock_path = %(lock_path)s
 property_protection_file = %(property_protection_file)s
@@ -632,8 +628,6 @@ image_member_quota=%(image_member_quota)s
 image_property_quota=%(image_property_quota)s
 image_tag_quota=%(image_tag_quota)s
 image_location_quota=%(image_location_quota)s
-location_strategy=%(location_strategy)s
-allow_additional_image_properties = True
 enabled_backends=file1:file,file2:file,file3:file
 [database]
 connection = %(sql_connection)s
@@ -643,8 +637,6 @@ policy_default_rule = %(policy_default_rule)s
 enforce_new_defaults=%(enforce_new_defaults)s
 [paste_deploy]
 flavor = %(deployment_flavor)s
-[store_type_location_strategy]
-store_type_preference = %(store_type_location_strategy_preference)s
 [glance_store]
 default_backend = %(default_backend)s
 [file1]
@@ -1134,15 +1126,6 @@ class FunctionalTest(test_utils.BaseTestCase):
         if self.include_scrubber:
             self.stop_server(self.scrubber_daemon)
 
-    def run_sql_cmd(self, sql):
-        """
-        Provides a crude mechanism to run manual SQL commands for backend
-        DB verification within the functional tests.
-        The raw result set is returned.
-        """
-        engine = db_api.get_engine()
-        return engine.execute(sql)
-
     def copy_data_file(self, file_name, dst_dir):
         src_file_name = os.path.join('glance/tests/etc', file_name)
         shutil.copy(src_file_name, dst_dir)
@@ -1486,15 +1469,6 @@ class MultipleBackendFunctionalTest(test_utils.BaseTestCase):
         if self.include_scrubber:
             self.stop_server(self.scrubber_daemon)
 
-    def run_sql_cmd(self, sql):
-        """
-        Provides a crude mechanism to run manual SQL commands for backend
-        DB verification within the functional tests.
-        The raw result set is returned.
-        """
-        engine = db_api.get_engine()
-        return engine.execute(sql)
-
     def copy_data_file(self, file_name, dst_dir):
         src_file_name = os.path.join('glance/tests/etc', file_name)
         shutil.copy(src_file_name, dst_dir)
