@@ -59,6 +59,7 @@ class TestConvertImageTask(test_utils.BaseTestCase):
         self.context = mock.MagicMock()
         self.img_repo = mock.MagicMock()
         self.task_repo = mock.MagicMock()
+        self.stores = mock.MagicMock()
         self.image_id = UUID1
 
         self.gateway = gateway.Gateway()
@@ -87,15 +88,18 @@ class TestConvertImageTask(test_utils.BaseTestCase):
                                                task_input=task_input)
 
         self.image.extra_properties = {
-            'os_glance_import_task': self.task.task_id}
+            'os_glance_import_task': self.task.task_id,
+            'os_glance_importing_to_stores': mock.MagicMock(),
+            'os_glance_failed_import': ""
+        }
         self.wrapper = import_flow.ImportActionWrapper(self.img_repo,
                                                        self.image_id,
                                                        self.task.task_id)
 
-        self.inspector_mock = mock.MagicMock()
+        self.detect_file_format_mock = mock.MagicMock()
         self.useFixture(fixtures.MockPatch('glance.common.format_inspector.'
-                                           'get_inspector',
-                                           self.inspector_mock))
+                                           'detect_file_format',
+                                           self.detect_file_format_mock))
 
     @mock.patch.object(os, 'stat')
     @mock.patch.object(os, 'remove')
@@ -105,7 +109,8 @@ class TestConvertImageTask(test_utils.BaseTestCase):
         image_convert = image_conversion._ConvertImage(self.context,
                                                        self.task.task_id,
                                                        self.task_type,
-                                                       self.wrapper)
+                                                       self.wrapper,
+                                                       self.stores)
 
         self.task_repo.get.return_value = self.task
         image = mock.MagicMock(image_id=self.image_id, virtual_size=None,
@@ -119,6 +124,9 @@ class TestConvertImageTask(test_utils.BaseTestCase):
             with mock.patch.object(json, 'loads') as jloads_mock:
                 jloads_mock.return_value = {'format': 'raw',
                                             'virtual-size': 456}
+                inspector = self.detect_file_format_mock.return_value
+                inspector.__str__.return_value = 'raw'
+                inspector.safety_check.return_value = True
                 image_convert.execute('file:///test/path.raw')
 
                 # NOTE(hemanthm): Asserting that the source format is passed
@@ -133,11 +141,57 @@ class TestConvertImageTask(test_utils.BaseTestCase):
         self.assertEqual(456, image.virtual_size)
         self.assertEqual(123, image.size)
 
+    @mock.patch('os.remove')
+    @mock.patch('os.stat')
+    @mock.patch('oslo_concurrency.processutils.trycmd')
+    @mock.patch('glance.async_.flows.plugins.image_conversion.LOG')
+    def test_image_convert_excluded_for_iso(self, mock_log, mock_run,
+                                            mock_stat, mock_remove, fmt='iso'):
+        mock_stat.return_value = mock.MagicMock(stsize=123)
+        stdout = json.dumps({'format': 'raw'})
+        mock_run.return_value = (stdout, '')
+        image_convert = image_conversion._ConvertImage(self.context,
+                                                       self.task.task_id,
+                                                       self.task_type,
+                                                       self.wrapper,
+                                                       self.stores)
+        self.task_repo.get.return_value = self.task
+        image = mock.MagicMock(image_id=self.image_id, virtual_size=None,
+                               extra_properties={
+                                   'os_glance_import_task': self.task.task_id},
+                               disk_format=fmt)
+
+        self.img_repo.get.return_value = image
+        inspector = self.detect_file_format_mock.return_value
+        inspector.__str__.return_value = 'iso'
+        inspector.safety_check.return_value = True
+
+        image_convert.execute('file:///test/path.iso')
+        self.assertEqual(fmt, image.disk_format)
+        mock_log.debug.assert_called_once_with(
+            "Avoiding conversion of an image %s having "
+            "`iso` disk format.", self.image_id)
+
+    def test_image_convert_iso_lie_raw(self):
+        e = self.assertRaises(
+            RuntimeError, self.test_image_convert_excluded_for_iso,
+            fmt='raw')
+        self.assertEqual('Image has disallowed configuration',
+                         str(e))
+
+    def test_image_convert_iso_lie_qcow2(self):
+        e = self.assertRaises(
+            RuntimeError, self.test_image_convert_excluded_for_iso,
+            fmt='qcow2')
+        self.assertEqual('Image has disallowed configuration',
+                         str(e))
+
     def _setup_image_convert_info_fail(self, disk_format='qcow2'):
         image_convert = image_conversion._ConvertImage(self.context,
                                                        self.task.task_id,
                                                        self.task_type,
-                                                       self.wrapper)
+                                                       self.wrapper,
+                                                       self.stores)
 
         self.task_repo.get.return_value = self.task
         image = mock.MagicMock(image_id=self.image_id, virtual_size=None,
@@ -150,6 +204,9 @@ class TestConvertImageTask(test_utils.BaseTestCase):
     def test_image_convert_fails_inspection(self):
         convert = self._setup_image_convert_info_fail()
         with mock.patch.object(processutils, 'execute') as exc_mock:
+            inspector = self.detect_file_format_mock.return_value
+            inspector.__str__.return_value = 'qcow2'
+            inspector.safety_check.return_value = True
             exc_mock.side_effect = OSError('fail')
             self.assertRaises(OSError,
                               convert.execute, 'file:///test/path.raw')
@@ -168,6 +225,9 @@ class TestConvertImageTask(test_utils.BaseTestCase):
         convert = self._setup_image_convert_info_fail()
         with mock.patch.object(processutils, 'execute') as exc_mock:
             exc_mock.return_value = '', 'some error'
+            inspector = self.detect_file_format_mock.return_value
+            inspector.__str__.return_value = 'qcow2'
+            inspector.safety_check.return_value = True
             self.assertRaises(RuntimeError,
                               convert.execute, 'file:///test/path.raw')
             exc_mock.assert_called_once_with(
@@ -187,6 +247,9 @@ class TestConvertImageTask(test_utils.BaseTestCase):
 
         convert = self._setup_image_convert_info_fail()
         with mock.patch.object(processutils, 'execute') as exc_mock:
+            inspector = self.detect_file_format_mock.return_value
+            inspector.__str__.return_value = 'qcow2'
+            inspector.safety_check.return_value = True
             exc_mock.return_value = json.dumps(data), ''
             e = self.assertRaises(RuntimeError,
                                   convert.execute, 'file:///test/path.qcow')
@@ -204,6 +267,9 @@ class TestConvertImageTask(test_utils.BaseTestCase):
         convert = self._setup_image_convert_info_fail()
         with mock.patch.object(processutils, 'execute') as exc_mock:
             exc_mock.return_value = json.dumps(data), ''
+            inspector = self.detect_file_format_mock.return_value
+            inspector.__str__.return_value = 'qcow2'
+            inspector.safety_check.return_value = True
             e = self.assertRaises(RuntimeError,
                                   convert.execute, 'file:///test/path.qcow')
             self.assertEqual('QCOW images with data-file set are not allowed',
@@ -211,14 +277,13 @@ class TestConvertImageTask(test_utils.BaseTestCase):
 
     def test_image_convert_no_inspector_match(self):
         convert = self._setup_image_convert_info_fail()
-        self.inspector_mock.return_value = None
         self.assertRaisesRegex(RuntimeError,
-                               'Unable to convert from format',
+                               'Image format mismatch',
                                convert.execute, 'file:///test/path.hpfs')
 
     def test_image_convert_fails_inspection_safety_check(self):
         convert = self._setup_image_convert_info_fail()
-        inspector = self.inspector_mock.return_value.from_file.return_value
+        inspector = self.detect_file_format_mock.return_value
         inspector.safety_check.return_value = False
         self.assertRaisesRegex(RuntimeError,
                                'Image has disallowed configuration',
@@ -226,7 +291,7 @@ class TestConvertImageTask(test_utils.BaseTestCase):
 
     def test_image_convert_fails_inspection_format_check(self):
         convert = self._setup_image_convert_info_fail()
-        self.inspector_mock.return_value.from_file.side_effect = (
+        self.detect_file_format_mock.side_effect = (
             format_inspector.ImageFormatError())
         self.assertRaisesRegex(RuntimeError,
                                'Image format detection failed',
@@ -234,7 +299,7 @@ class TestConvertImageTask(test_utils.BaseTestCase):
 
     def test_image_convert_fails_inspection_error(self):
         convert = self._setup_image_convert_info_fail()
-        self.inspector_mock.return_value.from_file.side_effect = ValueError
+        self.detect_file_format_mock.side_effect = ValueError
         self.assertRaisesRegex(RuntimeError,
                                'Unable to inspect image',
                                convert.execute, 'file:///test/path.qcow')
@@ -248,6 +313,9 @@ class TestConvertImageTask(test_utils.BaseTestCase):
 
         convert = self._setup_image_convert_info_fail(disk_format='vmdk')
         with mock.patch.object(processutils, 'execute') as exc_mock:
+            inspector = self.detect_file_format_mock.return_value
+            inspector.__str__.return_value = 'vmdk'
+            inspector.safety_check.return_value = True
             exc_mock.return_value = json.dumps(data), ''
             convert.execute('file:///test/path.vmdk')
 
@@ -277,6 +345,9 @@ class TestConvertImageTask(test_utils.BaseTestCase):
     def test_image_convert_fails(self):
         convert = self._setup_image_convert_info_fail(disk_format='raw')
         with mock.patch.object(processutils, 'execute') as exc_mock:
+            inspector = self.detect_file_format_mock.return_value
+            inspector.__str__.return_value = 'raw'
+            inspector.safety_check.return_value = True
             exc_mock.side_effect = [('{"format":"raw"}', ''),
                                     OSError('convert_fail')]
             self.assertRaises(OSError,
@@ -300,6 +371,9 @@ class TestConvertImageTask(test_utils.BaseTestCase):
         with mock.patch.object(processutils, 'execute') as exc_mock:
             exc_mock.side_effect = [('{"format":"raw"}', ''),
                                     ('', 'some error')]
+            inspector = self.detect_file_format_mock.return_value
+            inspector.__str__.return_value = 'raw'
+            inspector.safety_check.return_value = True
             self.assertRaises(RuntimeError,
                               convert.execute, 'file:///test/path.raw')
             exc_mock.assert_has_calls(
@@ -320,6 +394,9 @@ class TestConvertImageTask(test_utils.BaseTestCase):
         convert = self._setup_image_convert_info_fail()
         with mock.patch.object(processutils, 'execute') as exc_mock:
             exc_mock.return_value = ('{}', '')
+            inspector = self.detect_file_format_mock.return_value
+            inspector.__str__.return_value = 'qcow2'
+            inspector.safety_check.return_value = True
             exc = self.assertRaises(RuntimeError,
                                     convert.execute, 'file:///test/path.raw')
             self.assertIn('Image metadata disagrees about format', str(exc))
@@ -334,11 +411,25 @@ class TestConvertImageTask(test_utils.BaseTestCase):
         # Make sure we did not update the image
         self.img_repo.save.assert_not_called()
 
+    def test_image_convert_source_format_inspection_not_match(self):
+        convert = self._setup_image_convert_info_fail(disk_format="raw")
+        with mock.patch.object(processutils, 'execute') as exc_mock:
+            exc_mock.return_value = (
+                '{"format": "raw", "virtual-size": 123}', '')
+            inspector = self.detect_file_format_mock.return_value
+            inspector.__str__.return_value = 'qcow2'
+            exc = self.assertRaises(RuntimeError,
+                                    convert.execute, 'file:///test/path.raw')
+            self.assertIn('Image format mismatch', str(exc))
+
     def test_image_convert_same_format_does_nothing(self):
         convert = self._setup_image_convert_info_fail()
         with mock.patch.object(processutils, 'execute') as exc_mock:
             exc_mock.return_value = (
                 '{"format": "qcow2", "virtual-size": 123}', '')
+            inspector = self.detect_file_format_mock.return_value
+            inspector.__str__.return_value = 'qcow2'
+            inspector.safety_check.return_value = True
             convert.execute('file:///test/path.qcow')
             # Make sure we only called qemu-img for inspection, not conversion
             exc_mock.assert_called_once_with(
@@ -354,15 +445,23 @@ class TestConvertImageTask(test_utils.BaseTestCase):
         image = self.img_repo.get.return_value
         self.assertEqual(123, image.virtual_size)
 
-    @mock.patch.object(os, 'remove')
-    def test_image_convert_revert_success(self, mock_os_remove):
+    def _set_image_conversion(self, mock_os_remove, stores=[]):
         mock_os_remove.return_value = None
+        wrapper = mock.MagicMock()
         image_convert = image_conversion._ConvertImage(self.context,
                                                        self.task.task_id,
                                                        self.task_type,
-                                                       self.wrapper)
-
+                                                       wrapper,
+                                                       stores)
+        action = wrapper.__enter__.return_value
         self.task_repo.get.return_value = self.task
+        return action, image_convert
+
+    @mock.patch.object(os, 'remove')
+    def test_image_convert_revert_success_multiple_stores(
+            self, mock_os_remove):
+        action, image_convert = self._set_image_conversion(
+            mock_os_remove, stores=self.stores)
 
         with mock.patch.object(processutils, 'execute') as exc_mock:
             exc_mock.return_value = ("", None)
@@ -370,6 +469,48 @@ class TestConvertImageTask(test_utils.BaseTestCase):
                 os_exists_mock.return_value = True
                 image_convert.revert(result=mock.MagicMock())
                 self.assertEqual(1, mock_os_remove.call_count)
+                action.set_image_attribute.assert_called_once_with(
+                    status='queued')
+                action.remove_importing_stores.assert_called_once_with(
+                    self.stores)
+                action.add_failed_stores.assert_called_once_with(
+                    self.stores)
+
+    @mock.patch.object(os, 'remove')
+    def test_image_convert_revert_success_single_store(
+            self, mock_os_remove):
+        action, image_convert = self._set_image_conversion(mock_os_remove)
+
+        with mock.patch.object(processutils, 'execute') as exc_mock:
+            exc_mock.return_value = ("", None)
+            with mock.patch.object(os.path, 'exists') as os_exists_mock:
+                os_exists_mock.return_value = True
+                image_convert.revert(result=mock.MagicMock())
+                self.assertEqual(1, mock_os_remove.call_count)
+                self.assertEqual(0, action.remove_importing_stores.call_count)
+                self.assertEqual(0, action.add_failed_store.call_count)
+                action.set_image_attribute.assert_called_once_with(
+                    status='queued')
+
+    @mock.patch.object(os, 'remove')
+    def test_image_convert_revert_success_src_file_exists(
+            self, mock_os_remove):
+        action, image_convert = self._set_image_conversion(
+            mock_os_remove, stores=self.stores)
+        image_convert.src_path = mock.MagicMock()
+
+        with mock.patch.object(processutils, 'execute') as exc_mock:
+            exc_mock.return_value = ("", None)
+            with mock.patch.object(os.path, 'exists') as os_exists_mock:
+                os_exists_mock.return_value = True
+                image_convert.revert(result=mock.MagicMock())
+                action.set_image_attribute.assert_called_once_with(
+                    status='queued')
+                action.remove_importing_stores.assert_called_once_with(
+                    self.stores)
+                action.add_failed_stores.assert_called_once_with(
+                    self.stores)
+                self.assertEqual(2, mock_os_remove.call_count)
 
     def test_image_convert_interpreter_configured(self):
         # By default, wsgi.python_interpreter is None; if it is
@@ -380,5 +521,6 @@ class TestConvertImageTask(test_utils.BaseTestCase):
         convert = image_conversion._ConvertImage(self.context,
                                                  self.task.task_id,
                                                  self.task_type,
-                                                 self.wrapper)
+                                                 self.wrapper,
+                                                 self.stores)
         self.assertEqual(fake_interpreter, convert.python)
